@@ -10,7 +10,6 @@
 
 import mimetypes
 
-import six
 from flask import current_app
 from werkzeug.utils import import_string
 
@@ -30,7 +29,7 @@ def obj_or_import_string(value, default=None):
     :params default: Default object to return if the import fails.
     :returns: The imported object.
     """
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         return import_string(value)
     elif value:
         return value
