@@ -8,17 +8,14 @@
 
 """Files download/upload REST API similar to S3 for Invenio."""
 
-from __future__ import absolute_import, print_function
-
 import uuid
-from functools import partial, wraps
-
 from flask import Blueprint, abort, current_app, json, request
 from flask_login import current_user
+from functools import partial, wraps
 from invenio_db import db
 from invenio_rest import ContentNegotiatedMethodView
 from marshmallow import missing
-from six.moves.urllib.parse import parse_qsl
+from urllib.parse import parse_qsl
 from webargs import fields
 from webargs.flaskparser import use_kwargs
 
@@ -581,7 +578,7 @@ class ObjectResource(ContentNegotiatedMethodView):
                     ObjectVersionTag.create(obj, key, value)
 
         db.session.commit()
-        file_uploaded.send(obj)
+        file_uploaded.send(current_app._get_current_object(), obj=obj)
         return self.make_response(
             data=obj,
             context={
@@ -627,7 +624,7 @@ class ObjectResource(ContentNegotiatedMethodView):
             if obj.file_id:
                 remove_file_data.delay(str(obj.file_id))
         db.session.commit()
-        file_deleted.send(obj)
+        file_deleted.send(current_app._get_current_object(), obj=obj)
         return self.make_response('', 204)
 
     @staticmethod
@@ -653,7 +650,7 @@ class ObjectResource(ContentNegotiatedMethodView):
             current_app.logger.warning(
                 'File checksum mismatch detected.', extra=logger_data)
 
-        file_downloaded.send(obj)
+        file_downloaded.send(current_app._get_current_object(), obj=obj)
         return obj.send_file(restricted=restricted,
                              as_attachment=as_attachment)
 
