@@ -9,16 +9,13 @@
 
 """Storage module tests."""
 
-from __future__ import absolute_import, print_function
-
 import errno
 import os
-from os.path import dirname, exists, getsize, join
-
 import pytest
-from fs.errors import DirectoryNotEmptyError, ResourceNotFoundError
+from fs.errors import DirectoryNotEmpty, FSError
+from io import BytesIO
 from mock import patch
-from six import BytesIO
+from os.path import dirname, exists, getsize, join
 
 from invenio_files_rest.errors import FileSizeError, StorageError, \
     UnexpectedFileSizeError
@@ -63,14 +60,17 @@ def test_pyfs_delete(app, db, dummy_location):
     assert not exists(testurl)
 
     s = PyFSFileStorage(join(dummy_location.uri, 'anotherpath/data'))
-    pytest.raises(ResourceNotFoundError, s.delete)
+
+    # this used to raise a ResourceNotFound, but fs>=2.0 raises CreateFailed
+    # FSError is their last common ancestor
+    pytest.raises(FSError, s.delete)
 
 
 def test_pyfs_delete_fail(pyfs, pyfs_testpath):
     """Test init of files."""
     pyfs.save(BytesIO(b'somedata'))
     os.rename(pyfs_testpath, join(dirname(pyfs_testpath), 'newname'))
-    pytest.raises(DirectoryNotEmptyError, pyfs.delete)
+    pytest.raises(DirectoryNotEmpty, pyfs.delete)
 
 
 def test_pyfs_save(pyfs, pyfs_testpath, get_md5):
@@ -261,8 +261,7 @@ def test_pyfs_send_file_for_download(app, pyfs):
         res = pyfs.send_file('myfilename.txt', mimetype='text/plain',
                              checksum=checksum, as_attachment=True)
         assert res.status_code == 200
-        assert (res.headers['Content-Disposition'] ==
-                'attachment; filename=myfilename.txt')
+        assert res.headers["Content-Disposition"] == "attachment; filename=myfilename.txt"
 
 
 def test_pyfs_send_file_xss_prevention(app, pyfs):
