@@ -8,15 +8,12 @@
 
 """Test object related views."""
 
-from __future__ import absolute_import, print_function
-
-from datetime import timedelta
-
 import pytest
+from datetime import timedelta, timezone
 from flask import url_for
-from fs.opener import opener
+from fs.opener import open_fs as opendir
+from io import BytesIO
 from mock import patch
-from six import BytesIO
 from testutils import BadBytesIO, login_user
 
 from invenio_files_rest.models import FileInstance, ObjectVersion
@@ -136,8 +133,7 @@ def test_get_download(client, headers, bucket, objects, permissions):
         assert resp.status_code == 200
 
         # Check if the 'Content-Disposition' is an attachment
-        assert (resp.headers['Content-Disposition'] ==
-                'attachment; filename={0}'.format(obj.key))
+        assert resp.headers["Content-Disposition"] == "attachment; filename={0}".format(obj.key)
 
 
 def test_last_modified_utc_conversion(client, headers, bucket, permissions):
@@ -159,8 +155,11 @@ def test_last_modified_utc_conversion(client, headers, bucket, permissions):
     # GET the object and make sure the Last-Modified parameter in the header
     # is the same (sans the microseconds resolution) timestamp
     get_resp = client.get(object_url)
+    last_modified = get_resp.last_modified
+    if last_modified.tzinfo and not updated.tzinfo:
+        updated = updated.replace(tzinfo=timezone.utc)
     assert get_resp.status_code == 200
-    assert abs(get_resp.last_modified - updated) < timedelta(seconds=1)
+    assert abs(last_modified - updated) < timedelta(seconds=1)
 
 
 def test_get_unreadable_file(client, headers, bucket, objects, db,
@@ -421,7 +420,8 @@ def test_put_error(client, bucket, admin_user):
     assert FileInstance.query.count() == 0
     assert ObjectVersion.query.count() == 0
     # Ensure that the file was removed.
-    assert len(list(opener.opendir(bucket.location.uri).walk('.'))) == 3
+    fs = opendir(bucket.location.uri)
+    assert len(list(fs.walk('.'))) == 3
 
 
 def test_put_multipartform(client, bucket, admin_user):
@@ -599,7 +599,7 @@ def test_put_header_tags(app, client, bucket, permissions, get_md5, get_json):
     key = 'test.txt'
     headers = {
         app.config['FILES_REST_FILE_TAGS_HEADER']: (
-            'key1=val1;key2=val2;key3=val3')
+            'key1=val1&key2=val2&key3=val3')
     }
 
     login_user(client, permissions['bucket'])
@@ -623,8 +623,8 @@ def test_put_header_invalid_tags(app, client, bucket, permissions, get_md5,
     invalid = [
         # We don't test zero-length values/keys, because they are filtered out
         # from parse_qsl
-        ('a'*256, 'valid'),
-        ('valid', 'b'*256),
+        ('a' * 256, 'valid'),
+        ('valid', 'b' * 256),
     ]
 
     login_user(client, permissions['bucket'])
